@@ -1,4 +1,4 @@
-from exceptions.unexpected_error import UnexpectedError
+from paystack.api_exceptions.unexpected_error import UnexpectedError
 
 
 class TimeoutError(UnexpectedError):
