@@ -1,4 +1,4 @@
-from exceptions.paystack_error import paystackError
+from paystack.api_exceptions.paystack_error import paystackError
 
 class UpgradeRequiredError(paystackError):
     """
