@@ -1,4 +1,4 @@
-from paystack.exceptions.invalid_parameter import InvalidParameters
+from paystack.api_exceptions.invalid_parameter import InvalidParameters
 from paystack.gateways.gateway import BaseGateway
 
 
